@@ -3,9 +3,16 @@ from __future__ import annotations
 import os
 import re
 import sys
-from argparse import _ArgumentGroup  # noqa
-from argparse import _SubParsersAction  # noqa
-from argparse import SUPPRESS, Action, ArgumentParser, HelpFormatter
+from argparse import (
+    SUPPRESS,
+    Action,
+    ArgumentParser,
+    HelpFormatter,
+    _ArgumentGroup,
+    _StoreFalseAction,
+    _StoreTrueAction,
+    _SubParsersAction,
+)
 from collections import defaultdict, namedtuple
 from typing import Iterator, cast
 
@@ -24,7 +31,11 @@ from docutils.nodes import (
     strong,
     title,
 )
-from docutils.parsers.rst.directives import positive_int, unchanged, unchanged_required
+from docutils.parsers.rst.directives import (  # type: ignore # no stubs
+    positive_int,
+    unchanged,
+    unchanged_required,
+)
 from docutils.parsers.rst.states import RSTState, RSTStateMachine
 from docutils.statemachine import StringList
 from sphinx.domains.std import StandardDomain
@@ -36,7 +47,7 @@ TextAsDefault = namedtuple("TextAsDefault", ["text"])
 
 
 def make_id(key: str) -> str:
-    return "-".join(key.split()).rstrip("-").lower()
+    return "-".join(key.split()).rstrip("-")
 
 
 logger = getLogger(__name__)
@@ -51,13 +62,15 @@ class SphinxArgparseCli(SphinxDirective):
         "prog": unchanged,
         "title": unchanged,
         "usage_width": positive_int,
+        "group_title_prefix": unchanged,
+        "group_sub_title_prefix": unchanged,
     }
 
     def __init__(
         self,
         name: str,
         arguments: list[str],
-        options: dict[str, str],
+        options: dict[str, str | None],
         content: StringList,
         lineno: int,
         content_offset: int,
@@ -65,6 +78,8 @@ class SphinxArgparseCli(SphinxDirective):
         state: RSTState,
         state_machine: RSTStateMachine,
     ):
+        options.setdefault("group_title_prefix", None)
+        options.setdefault("group_sub_title_prefix", None)
         super().__init__(name, arguments, options, content, lineno, content_offset, block_text, state, state_machine)
         self._parser: ArgumentParser | None = None
         self._std_domain: StandardDomain = cast(StandardDomain, self.env.get_domain("std"))
@@ -81,17 +96,17 @@ class SphinxArgparseCli(SphinxDirective):
         return self._parser
 
     def load_sub_parsers(self) -> Iterator[tuple[list[str], str, ArgumentParser]]:
-        top_sub_parser = self.parser._subparsers  # noqa
+        top_sub_parser = self.parser._subparsers
         if not top_sub_parser:
             return
         parser_to_args: dict[int, list[str]] = defaultdict(list)
         str_to_parser: dict[str, ArgumentParser] = {}
-        sub_parser = cast(_SubParsersAction, top_sub_parser._group_actions[0])  # noqa
-        for key, parser in sub_parser._name_parser_map.items():  # noqa
+        sub_parser = cast(_SubParsersAction, top_sub_parser._group_actions[0])
+        for key, parser in sub_parser._name_parser_map.items():
             parser_to_args[id(parser)].append(key)
             str_to_parser[key] = parser
         done_parser: set[int] = set()
-        for name, parser in sub_parser.choices.items():  # noqa
+        for name, parser in sub_parser.choices.items():
             parser_id = id(parser)
             if parser_id in done_parser:
                 continue
@@ -116,8 +131,8 @@ class SphinxArgparseCli(SphinxDirective):
             home_section += desc_paragraph
         # construct groups excluding sub-parsers
         home_section += self._mk_usage(self.parser)
-        for group in self.parser._action_groups:  # noqa
-            if not group._group_actions or group is self.parser._subparsers:  # noqa
+        for group in self.parser._action_groups:
+            if not group._group_actions or group is self.parser._subparsers:
                 continue
             home_section += self._mk_option_group(group, prefix=self.parser.prog.split("/")[-1])
         # construct sub-parser
@@ -126,8 +141,12 @@ class SphinxArgparseCli(SphinxDirective):
         return [home_section]
 
     def _mk_option_group(self, group: _ArgumentGroup, prefix: str) -> section:
-        title_text = f"{prefix}{' ' if prefix else ''}{group.title}"
-        ref_id = make_id(title_text)
+        sub_title_prefix: str = self.options["group_sub_title_prefix"]
+        title_prefix = self.options["group_title_prefix"]
+
+        title_text = self._build_opt_grp_title(group, prefix, sub_title_prefix, title_prefix)
+        title_ref: str = f"{prefix}{' ' if prefix else ''}{group.title}"
+        ref_id = make_id(title_ref)
         # the text sadly needs to be prefixed, because otherwise the autosectionlabel will conflict
         header = title("", Text(title_text))
         group_section = section("", header, ids=[ref_id], names=[ref_id])
@@ -135,13 +154,36 @@ class SphinxArgparseCli(SphinxDirective):
             group_section += paragraph("", Text(group.description))
         self._register_ref(ref_id, title_text, group_section)
         opt_group = bullet_list()
-        for action in group._group_actions:  # noqa
+        for action in group._group_actions:
             point = self._mk_option_line(action, prefix)
             opt_group += point
         group_section += opt_group
         return group_section
 
-    def _mk_option_line(self, action: Action, prefix: str) -> list_item:  # noqa
+    def _build_opt_grp_title(self, group: _ArgumentGroup, prefix: str, sub_title_prefix: str, title_prefix: str) -> str:
+        title_text, elements = "", prefix.split(" ")
+        if title_prefix is not None:
+            title_prefix = title_prefix.replace("{prog}", elements[0])
+            if title_prefix:
+                title_text += f"{title_prefix} "
+            if " " in prefix:
+                if sub_title_prefix is not None:
+                    title_text = self._append_title(title_text, sub_title_prefix, elements[0], " ".join(elements[1:]))
+                else:
+                    title_text += f"{' '.join(prefix.split(' ')[1:])} "
+        else:
+            if " " in prefix:
+                if sub_title_prefix is not None:
+                    title_text += f"{elements[0]} "
+                    title_text = self._append_title(title_text, sub_title_prefix, elements[0], " ".join(elements[1:]))
+                else:
+                    title_text += f"{' '.join(elements[:2])} "
+            else:
+                title_text += f"{prefix} "
+        title_text += group.title or ""
+        return title_text
+
+    def _mk_option_line(self, action: Action, prefix: str) -> list_item:
         line = paragraph()
         as_key = action.dest
         if action.metavar:
@@ -169,7 +211,11 @@ class SphinxArgparseCli(SphinxDirective):
             line += Text(" - ")
             for content in cast(paragraph, temp.children[0]).children:
                 line += content
-        if action.default != SUPPRESS and not re.match(r".*[ (]default[s]? .*", (action.help or "")):
+        if (
+            action.default != SUPPRESS
+            and not re.match(r".*[ (]default[s]? .*", (action.help or ""))
+            and not isinstance(action, (_StoreTrueAction, _StoreFalseAction))
+        ):
             line += Text(" (default: ")
             line += literal(text=str(action.default).replace(os.getcwd(), "{cwd}"))
             line += Text(")")
@@ -205,24 +251,57 @@ class SphinxArgparseCli(SphinxDirective):
         self._std_domain.labels[name] = doc_name, ref_name, ref_title
 
     def _mk_sub_command(self, aliases: list[str], help_msg: str, parser: ArgumentParser) -> section:
-        title_text = f"{parser.prog}"
+        sub_title_prefix: str = self.options["group_sub_title_prefix"]
+        title_prefix: str = self.options["group_title_prefix"]
+
+        title_text = self._build_sub_cmd_title(parser, sub_title_prefix, title_prefix)
+        title_ref: str = parser.prog
         if aliases:
-            title_text += f" ({', '.join(aliases)})"
-        ref_id = make_id(title_text)
-        group_section = section("", title("", Text(title_text)), ids=[ref_id], names=[title_text])
-        self._register_ref(ref_id, title_text, group_section)
+            aliases_text: str = f" ({', '.join(aliases)})"
+            title_text += aliases_text
+            title_ref += aliases_text
+        title_text = title_text.strip()
+        ref_id = make_id(title_ref)
+        group_section = section("", title("", Text(title_text)), ids=[ref_id], names=[title_ref])
+        self._register_ref(ref_id, title_ref, group_section)
 
         command_desc = (parser.description or help_msg or "").strip()
         if command_desc:
             desc_paragraph = paragraph("", Text(command_desc))
             group_section += desc_paragraph
         group_section += self._mk_usage(parser)
-        for group in parser._action_groups:  # noqa
+        for group in parser._action_groups:
             if not group._group_actions:  # do not show empty groups
                 continue
             group_section += self._mk_option_group(group, prefix=parser.prog)
         return group_section
 
+    def _build_sub_cmd_title(self, parser: ArgumentParser, sub_title_prefix: str, title_prefix: str) -> str:
+        title_text, elements = "", parser.prog.split(" ")
+        if title_prefix is not None:
+            title_prefix = title_prefix.replace("{prog}", elements[0])
+            if title_prefix:
+                title_text += f"{title_prefix} "
+            if sub_title_prefix is not None:
+                title_text = self._append_title(title_text, sub_title_prefix, elements[0], elements[1])
+            else:
+                title_text += elements[1]
+        else:
+            if sub_title_prefix is not None:
+                title_text += f"{elements[0]} "
+                title_text = self._append_title(title_text, sub_title_prefix, elements[0], elements[1])
+            else:
+                title_text += parser.prog
+        return title_text.rstrip()
+
+    @staticmethod
+    def _append_title(title_text: str, sub_title_prefix: str, prog: str, sub_cmd: str) -> str:
+        if sub_title_prefix:
+            sub_title_prefix = sub_title_prefix.replace("{prog}", prog)
+            sub_title_prefix = sub_title_prefix.replace("{subcommand}", sub_cmd)
+            title_text += f"{sub_title_prefix} "
+        return title_text
+
     def _mk_usage(self, parser: ArgumentParser) -> literal_block:
         parser.formatter_class = lambda prog: HelpFormatter(prog, width=self.options.get("usage_width", 100))
         texts = parser.format_usage()[len("usage: ") :].splitlines()
